Name: remctl
Version: 3.13
Release: 6%{?dist}
Summary: Client/server for Kerberos-authenticated command execution

Group: Applications/Internet
License: MIT
URL: http://www.eyrie.org/~eagle/software/remctl
Source0: http://archives.eyrie.org/software/kerberos/remctl-%{version}.tar.xz

%if "%{php_version}" < "5.6"
%global ini_name     %{name}.ini
%else
%global ini_name     40-%{name}.ini
%endif

# Use systemd unit files on Fedora and RHEL 7.
%if 0%{?fedora} || 0%{?rhel} >= 7
  %global _with_systemd 1
%endif

%if 0%{?_with_systemd}
Requires(preun):  systemd
Requires(postun): systemd
Requires(post):   systemd
%endif

BuildRequires: libevent-devel
BuildRequires: krb5-devel
BuildRequires: pcre-devel
BuildRequires: perl-devel
BuildRequires: perl-generators
BuildRequires: perl(Module::Build)
BuildRequires: perl(Test::Pod)
BuildRequires: perl(Test::Spelling)
BuildRequires: php-devel
BuildRequires: python2-devel
%if 0%{?rhel} && 0%{?rhel} <= 6
BuildRequires: ruby
BuildRequires: ruby(abi) = 1.8
%endif
%if 0%{?fedora} || 0%{?rhel} >= 7
BuildRequires: ruby(release)
%endif
BuildRequires: ruby-devel
BuildRequires: rubygem(minitest)
%if 0%{?_with_systemd}
BuildRequires: systemd
BuildRequires: systemd-devel
%endif

# RHEL 6 compatibility for PHP
%if 0%{?el6}
%{!?php_inidir:	%{expand: %%global php_inidir %{_sysconfdir}/php.d }}
%endif

# RHEL 6 compatibility for Ruby
%if 0%{?el6}
%{!?ruby_vendorarchdir: %global ruby_vendorarchdir %(ruby -rrbconfig -e 'puts Config::CONFIG["vendorarchdir"] ')}
%endif

%description

remctl (the client) and remctld (the server) implement a client/server
protocol for running single commands on a remote host using Kerberos
v5 authentication and returning the output. They use a very simple
GSS-API-authenticated network protocol, combined with server-side ACL
support and a server configuration file that maps remctl commands to
programs that should be run when that command is called by an
authorised user.

%package devel
Summary: Development files needed to compile C programs against remctl
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel

remctl implements a client/server protocol for running single commands
on a remote host using Kerberos v5 authentication. If you want to develop
programs which use remctl's libraries, you need to install this package.

%package perl
Summary: Perl interface to remctl
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description perl
remctl implements a client/server protocol for running single commands 
on a remote host using Kerberos v5 authentication. If you want to use
remctl's Perl bindings, you need to install this package.

%package php
Summary: PHP interface to remctl
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires:     php(zend-abi) = %{php_zend_api}
Requires:     php(api) = %{php_core_api}

%description php
remctl implements a client/server protocol for running single commands
on a remote host using Kerberos v5 authentication. If you want to use
remctl's PHP bindings, you need to install this package.

%package python
Summary: Python interface to remctl
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: python

%description python
remctl implements a client/server protocol for running single commands
on a remote host using Kerberos v5 authentication. If you want to use
remctl's Python bindings, you need to install this package.

%package ruby
Summary: Ruby interface to remctl
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
%{?el6:Requires:  ruby(abi) = 1.8}
%if 0%{?fedora} || 0%{?rhel} >= 7
Requires: ruby(release)
%endif
Provides: ruby(remctl) = %{version}-%{release}

%description ruby
remctl implements a client/server protocol for running single commands
on a remote host using Kerberos v5 authentication. If you want to use
remctl's Ruby bindings, you need to install this package.

%prep
%setup -q

%build
export REMCTL_PERL_FLAGS="installdirs=vendor"
%configure \
	--with-pcre \
	--enable-perl \
	--enable-php \
	--enable-python \
	--enable-ruby \
	--disable-static
make
# Parallel builds are currently broken but hopefully fixed upstream.
# (Commit 5127bef5f3e771e3f142dc84ae88879eddc40a41)
# That should land in remctl > 3.2.
#make %%{?_smp_mflags}

%check
# tests fail on various dists for now
#make check

%install
make install \
	DESTDIR=%{buildroot} \
	INSTALL="install -p" \
	RUBYARCHDIR="%{buildroot}%{ruby_vendorarchdir}" \

chmod 0755 %{buildroot}%{perl_vendorarch}/auto/Net/Remctl/Remctl.so
chmod 0644 %{buildroot}%{perl_vendorarch}/Net/Remctl.pm
chmod 0644 %{buildroot}%{_mandir}/man3/Net::Remctl.3pm*

# Tidy up the perl installation ...
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name perllocal.pod -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} 2>/dev/null ';'

# And the libraries
find %{buildroot} -type f -name '*.la' -exec rm -f {} ';'

# PHP configuration
mkdir -p %{buildroot}%{php_inidir}
install -p php/remctl.ini %{buildroot}%{php_inidir}/%{ini_name}

# Install PHP, Python, Ruby READMEs
for d in php python ruby; do
  %if 0%{?fedora} || 0%{?rhel} >= 8
    # https://fedoraproject.org/wiki/Changes/UnversionedDocdirs
    subpackage_docdir=%{_docdir}/%{name}-${d}
  %else
    subpackage_docdir=%{_docdir}/%{name}-${d}-%{version}
  %endif
  mkdir -p %{buildroot}${subpackage_docdir}
  install -p ${d}/README %{buildroot}${subpackage_docdir}/README
done

%post
/sbin/ldconfig
%if 0%{?_with_systemd}
  %systemd_post remctld.service
%endif

%preun
%if 0%{?_with_systemd}
  %systemd_preun remctld.service
%endif

%postun
/sbin/ldconfig
%if 0%{?_with_systemd}
  %systemd_postun remctld.service
%endif

%files 
%doc README NEWS TODO
%{_libdir}/*.so.*
%{_bindir}/remctl
%{_sbindir}/remctld
%{_sbindir}/remctl-shell
%{_mandir}/man1/remctl*
%{_mandir}/man8/remctl*
%if 0%{?_with_systemd}
%{_unitdir}/remctld.service
%{_unitdir}/remctld.socket
%endif

%files devel
%{_includedir}/remctl.h
%{_mandir}/man3/remctl*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libremctl.pc

%files perl
%{perl_vendorarch}/Net
%{perl_vendorarch}/auto/Net
%{_mandir}/man3/Net::Remctl*

%files php
%doc README
%{php_extdir}/remctl.so
%config(noreplace) %{php_inidir}/%{ini_name}

%files python
%doc README
%{python_sitearch}/_remctl.so
%{python_sitearch}/remctl.py*
%{python_sitearch}/pyremctl-%{version}-*.egg-info

%files ruby
%doc README
%{ruby_vendorarchdir}/remctl.so


%changelog
* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.13-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue Jun 06 2017 Jitka Plesnikova <jplesnik@redhat.com> - 3.13-4
- Perl 5.26 rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.13-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jan 13 2017 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.13-2
- F-26: rebuild for ruby24

* Sun Jan 08 2017 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.13-1
- Update to 3.13
- Drop EL5 compatibility

* Thu Nov 24 2016 Remi Collet <remi@fedoraproject.org> - 3.11-4
- rebuild for https://fedoraproject.org/wiki/Changes/php71

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.11-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu May 19 2016 Jitka Plesnikova <jplesnik@redhat.com> - 3.11-2
- Perl 5.24 re-rebuild of bootstrapped packages

* Thu May 19 2016 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.11-1
- Update to remctl 3.11

* Mon May 16 2016 Jitka Plesnikova <jplesnik@redhat.com> - 3.9-12
- Perl 5.24 rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.9-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jan 12 2016 Vít Ondruch <vondruch@redhat.com> - 3.9-10
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.3

* Wed Jul 01 2015 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.9-9
- Remove Fedora 19 workarounds, since that is EOL

* Wed Jul 01 2015 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.9-8
- BR: systemd in order to fix FTBFS (rhbz#1238103)

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.9-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 06 2015 Jitka Plesnikova <jplesnik@redhat.com> - 3.9-6
- Perl 5.22 rebuild

* Sat Jan 17 2015 Mamoru TASAKA <mtasaka@fedoraproject.org> - 3.9-5
- Rebuild for https://fedoraproject.org/wiki/Changes/Ruby_2.2

* Fri Aug 29 2014 Jitka Plesnikova <jplesnik@redhat.com> - 3.9-4
- Perl 5.20 rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jul 03 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.9-1
- Update to remctl 3.9
- Adjust Makefile for GCC on EL5

* Thu Jun 19 2014 Remi Collet <rcollet@redhat.com> - 3.8-5
- rebuild for https://fedoraproject.org/wiki/Changes/Php56
- add numerical prefix to extension configuration file

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Apr 22 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.8-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.1

* Sat Feb 08 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.8-2
- Add tarball for 3.8

* Sat Feb 08 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.8-1
- Update to 3.8
- Alphabetize BRs
- Optimize python file list (#1062765, thanks Remi Ferrand)
- Enable pcre support (#1062765, thanks Remi Ferrand)

* Fri Jan 24 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.7-2
- Adjust UnversionedDocdirs conditional to support Fedora 19

* Thu Jan 23 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.7-1
- Update to 3.7
- Drop upstreamed EL5 perl patch
- Drop RPM conditionals for Fedoras earlier than 19
- Add systemd support
- Use upstream's php.ini instead of our own
- Ship upstream's READMEs for PHP, Python, and Ruby

* Wed Aug 21 2013 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.6-1
- Upgrade to 3.6
- Drop upstreamed EL5 gcc patch

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 3.5-2
- Perl 5.18 rebuild

* Tue Jul 16 2013 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.5-1
- Upgrade to 3.5
- Switch to using upstream's xz tarballs
- Patch for EL5's gcc and Module::Build
- Add BR for tests
- Correct old changelog dates

* Fri Mar 22 2013 Remi Collet <rcollet@redhat.com> - 3.3-4
- rebuild for http://fedoraproject.org/wiki/Features/Php55

* Wed Mar 13 2013 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.3-3
- Adjust RPM conditionals for new Ruby guidelines on Fedora 19
- Add workaround for Ruby 2.0 "make install" bug (#921650)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Sep 26 2012 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.3-1
- Upgrade to 3.3

* Mon Sep 03 2012 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.2-5
- Fix PHP build for EL5
- Add remctl.ini PHP file

* Mon Sep 03 2012 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.2-4
- Add PHP, Python, and Ruby bindings
- Drop separate Perl "vendor" patch in favor of using REMCTL_PERL_FLAGS

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jun 28 2012 Petr Pisar <ppisar@redhat.com> - 3.2-2
- Perl 5.16 rebuild

* Wed Jun 20 2012 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.2-1
- Upgrade to 3.2

* Mon Jun 11 2012 Petr Pisar <ppisar@redhat.com> - 3.1-2
- Perl 5.16 rebuild

* Wed Feb 29 2012 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.1-1
- Upgrade to 3.1

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Nov 23 2011 Ken Dreyer <ktdreyer@ktdreyer.com> - 3.0-1
- Upgrade to 3.0

* Fri Jun 17 2011 Marcela Mašláňová <mmaslano@redhat.com> - 2.11-13
- Perl mass rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.11-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jun 02 2010 Marcela Maslanova <mmaslano@redhat.com> - 2.11-11
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 2.11-10
- rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.11-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.11-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jul 03 2008 Simon Wilkinson <simon@sxw.org.uk> 2.11-7
- Update to catch new perl version, and fix perl dependencies (#453579)

* Thu Feb 28 2008 Simon Wilkinson <simon@sxw.org.uk> 2.11-6
- The build process isn't -j safe, so remove smpflags until this can be fixed.

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.11-5
- Autorebuild for GCC 4.3

* Sun Jan 27 2008 Simon Wilkinson <simon@sxw.org.uk> 2.11-4
- More changes to address review comments

* Wed Jan 23 2008 Simon Wilkinson <simon@sxw.org.uk> 2.11-3
- Modifications for second round of review comments

* Tue Jan 22 2008 Simon Wilkinson <simon@sxw.org.uk> 2.11-2
- Modifications for first round of review comments
- Put perl modules in vendor_lib

* Mon Jan 14 2008 Simon Wilkinson <simon@sxw.org.uk> 2.11-1
- Upgrade to remctl 2.11

* Mon Oct  1 2007 Simon Wilkinson <simon@sxw.org.uk> 2.10-1
- Upgrade to remctl 2.10

* Sun Sep  2 2007 Simon Wilkinson <simon@sxw.org.uk> 2.9-1
- Initial specfile

